==> haskell-data-checked-0.3-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-checked.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-checked
version:              0.3
visibility:           public
id:                   data-checked-0.3-HLhMPujFBF2Hk66rSiqtaA
key:                  data-checked-0.3-HLhMPujFBF2Hk66rSiqtaA
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-checked
synopsis:             Type-indexed runtime-checked properties
description:
    This package provides a (phantom) type-indexed newtype evidence-wrapper for
    values that are checked to satisfy the property associated with the type.

category:             Data
abi:                  8cf5473014e1fd4c612aae49adaa4ec9
exposed:              True
exposed-modules:      Data.Checked Data.Checked.Strict
import-dirs:          /usr/lib/ghc-8.8.3/site-local/data-checked-0.3
library-dirs:         /usr/lib/ghc-8.8.3/site-local/data-checked-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/data-checked-0.3
hs-libraries:         HSdata-checked-0.3-HLhMPujFBF2Hk66rSiqtaA
depends:              base-4.13.0.0 deepseq-1.4.4.0
haddock-interfaces:
    /usr/share/doc/haskell-data-checked/html/data-checked.haddock

haddock-html:         /usr/share/doc/haskell-data-checked/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-checked-0.3-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-checked.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-checked
version:              0.3
visibility:           public
id:                   data-checked-0.3-9RHs1un5fmvBhDDz7uZ9V1
key:                  data-checked-0.3-9RHs1un5fmvBhDDz7uZ9V1
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-checked
synopsis:             Type-indexed runtime-checked properties 
description:
    This package provides a (phantom) type-indexed newtype evidence-wrapper for
    values that are checked to satisfy the property associated with the type.

category:             Data
abi:                  282a2369c5c16abd46c6943f4cae4984
exposed:              True
exposed-modules:      Data.Checked Data.Checked.Strict
import-dirs:          /usr/lib/ghc-8.10.1/site-local/data-checked-0.3
library-dirs:         /usr/lib/ghc-8.10.1/site-local/data-checked-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/data-checked-0.3
hs-libraries:         HSdata-checked-0.3-9RHs1un5fmvBhDDz7uZ9V1
depends:              base-4.14.0.0 deepseq-1.4.4.0
haddock-interfaces:
    /usr/share/doc/haskell-data-checked/html/data-checked.haddock

haddock-html:         /usr/share/doc/haskell-data-checked/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
